# Ablaufplanung und Aufwandsschätzung
## Ablaufplanung mit Netzplantechnik
### Übersicht / Kontext

* **Ziel:** Schritt-für-Schritt-Anleitung zur Erstellung eines Netzplans (Projektmanagement)
* **Fokus:**

    * **Vorwärtsplanung** (früheste Anfangs- und Endzeiten)
    * **Rückwärtsplanung** (späteste Anfangs- und Endzeiten)
* **Verwendung:** Netzplantechnik (PERT/CPM) zur Termin‑ und Abhängigkeitsplanung

### 1. Projektdaten definieren

* Jeder **Aufgabe** werden vergeben:

    * **Dauer** (in Tagen/Stunden)
    * **Vorgänger-Aufgaben**
* Ziel: visuelle Struktur aller Aufgaben und deren Abhängigkeiten

### 2. Netzplan zeichnen

1. **Knoten** (meist Rechtecke) repräsentieren Aufgaben
2. **Pfeile** zeigen Abhängigkeiten (z.B. Task A → Task B)
3. Netzplan erhält dadurch einen **Ablaufgraphen**

![image_885.png](image_885.png)

### 3. Vorwärtsrechnung

* Beginnt am **Projektstart (Tag0)**
* Für jede Aufgabe:

    * **FAZ (früheste Anfangszeit)** = maximaler EFA aller Vorgänger
    * **FEZ (früheste Endzeit)** = FAZ + Dauer
* Durchlaufen des Graphen von Start bis ende → bestmögliche früheste Termine

![image_886.png](image_886.png)

### 4. Rückwärtsrechnung

* Beginnt am **Projektende** (max FEZ aller End-Knoten)
* Für jede Aufgabe:

    * **SEZ (späteste Endzeit)** = minimaler SAZ aller Nachfolger
    * **SAZ (späteste Anfangszeit)** = SEZ - Dauer
* Rücklaufen durch Graph von Ende bis Start → späteste, noch termintreue Zeiten

![image_887.png](image_887.png)

### 5. Pufferzeiten berechnen

* **Gesamtpuffer** =SAZ - FAZ = SEZ - FEZ

    * Puffer = Zeitspielraum, um Verspätung ohne Projektauswirkung abzufangen
* **Freier Puffer** =FAZ des Nachfolgers - FEZ der aktuellen Aufgabe
* Aufgaben mit **Puffer = 0** bilden den **kritischen Pfad**

### 6. Kritischer Pfad

* Definition: Kombination aus Aufgaben mit **Null-Gesamtpuffer**
* Kennzeichnend: Jede Verzögerung dort verzögert den gesamten Projektabschluss
* Identifizierung durch markierte Knoten/Pfade → Fokus für Projekt-Monitoring

### Bedeutung für Projektmanagement

* Netzplan verschafft:
    * **Transparenz** über Abhängigkeiten und Zeitreserven
    * **Erkennen von Engpässen** (kritischer Pfad)
    * **Basis für Terminsteuerung** und Ressourcenplanung
* Ideal für komplexe Projekte mit vielen Abhängigkeiten

### Tipps & Hinweise

* **Sorgfältig initiale Daten eingeben** (Dauer, Vorgänger)
* Bei Änderungen: Netzplan neu berechnen
* Bei großen Projekten: Einsatz von Software (z.B. MS Project, Open-Source-Tools) empfohlen
* Wichtig: Die Methode gilt auch für andere Einheiten (z.B. Stunden, Wochen)

### Fazit

* Netzplantechnik = strukturierte Methode für Terminplanung
* Herangehensweise: **Vorwärts- + Rückwärtsrechnung**
* **Pufferzeiten** zeigen Flexibilität
* **Kritischer Pfad** definiert Projektzieltermin
* Hilft bei **Terminkontrolle**, **Ressourcenzuteilung** und **Frühwarnung für Probleme**

## Aufwandsschätzung
- werden für viele Zwecke benötigt:
  - Projektplanung
    - Termine, Personalbedarf, Kosten
  - Angebotsabgabe
    - Richtpreise, Festpreise, Selbstkostenerstattung
  - Projektsteuerung
  - Zwischen- /Nachkalkulation
  - Lieferanten-Preisüberwachung
- **große Bedeutung für Projekterfolg**

- Optimale Projektdauer
  - $Projektdauer [Monate] = 3*\sqrt[3]{Aufwand [PM]}$

### Best Practices
- immer wieder gemäß dem Projektfortschritt anpassen
- offensives Kommunizieren von Unsicherheiten
- Experten hinzuziehen
- Historische Daten nutzen

### Motivation für Schätzung
- Falsche Schätzung hat negative Auswirkungen:
  - Über- / Unterforderung
  - Unzufriedenheit
  - Projektverzögerung
- Trotzdem besser als keine Schätzung
  - bietet dennoch Orientierung
- Mit dem Fortschritt des Projekts wird die Schätzung immer genauer
  - ![image_888.png](image_888.png)

### Unterscheidung von Aufwand und Dauer
- **Aufwand**: Zeit, die tatsächlich für eine Aufgabe benötigt wird
  - wird gemessen in Personentagen, -stunden, -monaten
  - z.B. 10 Stunden Arbeit
- **Dauer**: Zeitraum, in dem die Aufgabe erledigt wird
  - wird gemessen in Kalendertagen, -stunden, -wochen
    - z.B. 2 Tage (inkl. Pausen, Wartezeiten)
  - $Dauer = Arbeitsmenge / Ressourcenkapazität$
- **Balance zwischen Aufwand und Dauer**
  - ![image_890.png](image_890.png)
  - Kürzere Dauer
    - höherer Ressourcenaufwand
    - Mehr Hektik, Fehler
  - Längere Dauer
    - längere Laufzeit Infrastrukturkosten
    - Motivationsverlust aufgrund langsamer Fortschritte

### Schätz- Objekte, Methoden, Prozess
#### Schätzobjekte
- Entwicklungsprozess
  - Aufwand für einzelne Aktivitäten / Phasen
- Output-Objekte
  - Aufwand für einzelne Aufwandseinheiten
    - _Lieferobjekte, Subsysteme, Module, etc._
- Komplexität
  - Komplexitätsgrad eines Systems
    - _z.B. Anzahl der Schnittstellen, Datenbankkomplexität, etc._

1. Schätzobjekte, Attribute festlegen
   - bspw.
     - Phasen im Entwicklungsprozess
     - Input- und Output-Objekte
     - Komplexität
     - Anzahl Anforderungen
     - Anzahl Schnittstellen
2. Umrechnung von Aufwand in Dauer
   - Berücksichtigung von
     - Pausen
     - Qualifikation
     - Vor-/Nacharbeit
     - Dokumentation
     - ...
   - $Bruttoaufwand = Nettoaufwand * Einsatzfaktor * Fähigkeitsfaktor$
     - Einsatzfaktor: Berücksichtigung von Pausen, Vor-/Nacharbeit, etc.
     - Fähigkeitsfaktor: Berücksichtigung von Qualifikation, Erfahrung, etc.
   - Bsp:
     - ![image_889.png](image_889.png)


#### Schätzmethoden
- **Analogiemethoden**
  - beruhen auf Vergleichbarkeit mit ähnlichen Projekten
    - ähnliche Aufgabe, Größe, Randbedingungen
  - je genauer und aktueller die Vergleichsdaten, desto besser
  - Bewertung:
    - | Vorteile                                                   | Nachteile                                    |
      |------------------------------------------------------------|----------------------------------------------|
      | bereits früh möglich                                       | schwierige Beurteilung der Repräsentativität |
      | Aufwand von Ist-Werten abgeleitet                          | hohe Subjektivität der Zu-/Abschläge         |
      | Schätzungen sowohl auf Gesamt, als auch auf Subsystemebene |                                              |
- **Prozentsatzmethode, Extrapolationsverfahren**
  - Auf Basis von Erfahrungswerten
    - mithilfe von Extrapolation in die Zukunft projizieren
  - benötigt historische Daten
    - Aufteilung von Aufwand prozentual auf einzelne Phasen
    - Eindeutig definierte Phasen
    - Stabilität der Umweltbedingungen
- **Expertenschätzung**


#### Schätzprozess und Ergebnis
  - Top-Down
    - Zunächst Grobschätzung für Gesamtprojekt
    - Dann Verfeinerung
  - Bottom-Up
    - Zunächst Detaillierung der einzelnen Aufgaben
    - Dann Summenbildung
  - Einzelwert vs. Bereichsschätzungen

